Feedforward Closedloop Learning: feedforward_closedloop_learning.LearningThread Class Reference

Feedforward Closedloop Learning

Public Member Functions | Properties | List of all members
feedforward_closedloop_learning.LearningThread Class Reference
Inheritance diagram for feedforward_closedloop_learning.LearningThread:
[legend]
Collaboration diagram for feedforward_closedloop_learning.LearningThread:
[legend]

## Public Member Functions
def | __init__ (self, *args, **kwargs)
Public Member Functions inherited from feedforward_closedloop_learning.LayerThread
"void" | addNeuron (self, "Neuron" neuron)
"void" | start (self)
"void" | join (self)
"void" | run (self)

## Properties
| thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
Properties inherited from feedforward_closedloop_learning.LayerThread
| thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

## Detailed Description

    Proxy of C++ LearningThread class.

The documentation for this class was generated from the following file:

- feedforward_closedloop_learning.py